@@ -58,7 +58,7 @@ class Freebox(IPlugin):
 				log.msg(" boy  :  %s" % (rs['boy']))
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
-				if rs['idx_sec'] = "2":
+				if rs['idx_sec'] == "2":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre   len(maliste)
 					lg=len(rs['idx'])		
@@ -82,7 +82,7 @@ class Freebox(IPlugin):
 								log.msg("idx  :  %s" % (rs['idx']))
 								resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 							log.msg("resp  :  %s" % (resp))
-				if rs['idx_sec'] = "1":
+				if rs['idx_sec'] == "1":
 					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 					log.msg("resp unique   :  %s" % (resp))
